// java wrapper for vtkXMLRectilinearGridReader object
//

package vtk;
import vtk.*;

public class vtkXMLRectilinearGridReader extends vtkXMLStructuredDataReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkRectilinearGrid GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkRectilinearGrid GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkXMLRectilinearGridReader() { super(); }

  public vtkXMLRectilinearGridReader(long id) { super(id); }
  public native long   VTKInit();

}
